==> tecfy_core_package-1.0.23.tar.gz: lib/views/general/local_records.page.dart <==
part of tecfy_core_client_package;

class LocalRecordsPage extends StatefulWidget {
  @override
  _LocalRecordsPageState createState() => _LocalRecordsPageState();
}

class _LocalRecordsPageState extends AppState<LocalRecordsPage> {
  List<dynamic>? _data;
  late ScrollController _scrollController;
  late StreamSubscription<bool> _streamSubscription;
  @override
  initState() {
    _scrollController = ScrollController();
    TecfySyncService.getLocalRecords().then((d) {
      _data = d;
      setState(() {});
    });
    _streamSubscription = TecfySyncService.syncWidgetStream.listen((event) {
      if (event && _data != null) return;
      TecfySyncService.getLocalRecords().then((d) {
        _data = d;
        setState(() {});
      });
    });
    super.initState();
  }

  @override
  void dispose() {
    _scrollController.dispose();
    _streamSubscription.cancel();
    super.dispose();
  }

  _onTab(item) async {
    if (item['type'] == 'Delete') {
      var result = await AppNavigator.confirmMessage(
          context, 'Are you sure you want to undo Delete?');
      if (result) {
        await TecfySyncService.undoDelete(item['id']);
        _data = await TecfySyncService.getLocalRecords();
        setState(() {});
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(
        context, AppLocale.translate(context, 'Local Database'), 'settings',
        isMobile: LayoutService.isMobile(context),
        appBarActions: [
          TecfySyncService.getSyncIcon(context, true)
          // TecfySyncService.isSyncing
          //     ? CircularProgressIndicator()
          //     : IconButton(
          //         tooltip: trans('Sync'),
          //         icon: Icon(Icons.sync_alt),
          //         onPressed: () async {
          //           TecfySyncService.isSyncing = true;
          //           setState(() {});
          //           var result =
          //               await TecfySyncService.syncNow(context: context);
          //           TecfySyncService.isSyncing = false;
          //           if (result.success) {
          //             AppNavigator.showMessage(context, 'تمت العملية بنجاح',
          //                 type: MessageType.success);
          //             _data = await TecfySyncService.getLocalRecords();
          //           } else {
          //             AppNavigator.showMessage(context, 'Error',
          //                 message:
          //                     result.message ?? 'خطأ اثناء المزامنه مع السيرفر',
          //                 type: MessageType.error);
          //           }
          //           setState(() {});
          //         })
        ],
        child: _data == null
            ? Center(child: CircularProgressIndicator())
            : Scrollbar(
                isAlwaysShown: true,
                showTrackOnHover: true,
                controller: _scrollController,
                child: SingleChildScrollView(
                  controller: _scrollController,
                  child: DataTable(
                    showCheckboxColumn: true,
                    sortColumnIndex: 0,
                    sortAscending: false,
                    columns: [
                      DataColumn(label: Text(trans('Entity')), numeric: false),
                      DataColumn(label: Text(trans('Count')), numeric: true),
                    ],
                    rows: _data
                            ?.map<DataRow>((d) => DataRow(
                                  cells: [
                                    DataCell(
                                        Text(d['entityName'] ??
                                            d['entity'] ??
                                            ''),
                                        onTap: () => _onTab(d)),
                                    DataCell(Text(d['count'].toString()),
                                        onTap: () => _onTab(d)),
                                    // DataCell(Text(d['message'] ?? ''),
                                    //     onTap: () => onTab(d)),
                                  ],
                                ))
                            .toList() ??
                        [],
                  ),
                ),
              ));
  }
}

==> tecfy_core_package-1.0.41.tar.gz: lib/views/general/local_records.page.dart <==
part of tecfy_core_client_package;

class LocalRecordsPage extends StatefulWidget {
  @override
  _LocalRecordsPageState createState() => _LocalRecordsPageState();
}

class _LocalRecordsPageState extends AppState<LocalRecordsPage> {
  List<dynamic>? _data;
  late ScrollController _scrollController;
  late StreamSubscription<bool> _streamSubscription;
  @override
  initState() {
    _scrollController = ScrollController();
    TecfySyncService.getLocalRecords().then((d) {
      _data = d;
      setState(() {});
    });
    _streamSubscription = TecfySyncService.syncWidgetStream.listen((event) {
      if (event && _data != null) return;
      TecfySyncService.getLocalRecords().then((d) {
        _data = d;
        setState(() {});
      });
    });
    super.initState();
  }

  @override
  void dispose() {
    _scrollController.dispose();
    _streamSubscription.cancel();
    super.dispose();
  }

  _onTab(item) async {
    if (item['type'] == 'Delete') {
      var result = await AppNavigator.confirmMessage(
          context, 'Are you sure you want to undo Delete?');
      if (result) {
        await TecfySyncService.undoDelete(item['id']);
        _data = await TecfySyncService.getLocalRecords();
        setState(() {});
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(context, AppLocale.translate('Local Database'), 'settings',
        isMobile: LayoutService.isMobile(context),
        appBarActions: [
          TecfySyncService.getSyncIcon(context, true)
          // TecfySyncService.isSyncing
          //     ? CircularProgressIndicator()
          //     : IconButton(
          //         tooltip: trans('Sync'),
          //         icon: Icon(Icons.sync_alt),
          //         onPressed: () async {
          //           TecfySyncService.isSyncing = true;
          //           setState(() {});
          //           var result =
          //               await TecfySyncService.syncNow(context: context);
          //           TecfySyncService.isSyncing = false;
          //           if (result.success) {
          //             AppNavigator.showMessage(context, 'تمت العملية بنجاح',
          //                 type: MessageType.success);
          //             _data = await TecfySyncService.getLocalRecords();
          //           } else {
          //             AppNavigator.showMessage(context, 'Error',
          //                 message:
          //                     result.message ?? 'خطأ اثناء المزامنه مع السيرفر',
          //                 type: MessageType.error);
          //           }
          //           setState(() {});
          //         })
        ],
        child: _data == null
            ? Center(child: CircularProgressIndicator())
            : Scrollbar(
                isAlwaysShown: true,
                showTrackOnHover: true,
                controller: _scrollController,
                child: SingleChildScrollView(
                  controller: _scrollController,
                  child: DataTable(
                    showCheckboxColumn: true,
                    sortColumnIndex: 0,
                    sortAscending: false,
                    columns: [
                      DataColumn(label: Text(trans('Entity')), numeric: false),
                      DataColumn(label: Text(trans('Count')), numeric: true),
                    ],
                    rows: _data
                            ?.map<DataRow>((d) => DataRow(
                                  cells: [
                                    DataCell(
                                        Text(d['entityName'] ??
                                            d['entity'] ??
                                            ''),
                                        onTap: () => _onTab(d)),
                                    DataCell(Text(d['count'].toString()),
                                        onTap: () => _onTab(d)),
                                    // DataCell(Text(d['message'] ?? ''),
                                    //     onTap: () => onTab(d)),
                                  ],
                                ))
                            .toList() ??
                        [],
                  ),
                ),
              ));
  }
}
